Configurator
================================

About
---------------

.. automodule:: bc_configs.configurator
   :members:
   :undoc-members:
   :show-inheritance:

BaseConfig
------------------------------------------

.. automodule:: bc_configs.configurator.BaseConfig
   :members:
   :undoc-members:
   :show-inheritance:
